@@ -1,13 +1,13 @@
 from gensim.models import word2vec
 from modelstore.model_store import ModelStore
 
-from libraries.util.datasets import load_newsgroup_sentences
+from libraries.util.datasets import load_text_dataset
 from libraries.util.domains import NEWSGROUP_EMBEDDINGS_DOMAIN
 
 
 def _train_example_model() -> word2vec.Word2Vec:
     # Load the data
-    sentences = load_newsgroup_sentences()
+    sentences = load_text_dataset()
 
     # Train a word2vec model
     print(f"🤖  Training a word2vec model...")
@@ -30,12 +30,10 @@ def train_and_upload(modelstore: ModelStore) -> dict:
     return meta_data
 
 
-def load_and_test(modelstore: ModelStore, model_id: str):
+def load_and_test(modelstore: ModelStore, model_domain: str, model_id: str):
     # Load the model back into memory!
-    print(
-        f'⤵️  Loading the word2vec "{NEWSGROUP_EMBEDDINGS_DOMAIN}" domain model={model_id}'
-    )
-    model = modelstore.load(NEWSGROUP_EMBEDDINGS_DOMAIN, model_id)
+    print(f'⤵️  Loading the word2vec "{model_domain}" domain model={model_id}')
+    model = modelstore.load(model_domain, model_id)
 
     # Find some nearest neighbours
     most_similar = set([k[0] for k in model.wv.most_similar("cool", topn=5)])
