@@ -1,6 +1,9 @@
 set -e
 backends=( filesystem aws azure gcloud )
-frameworks=( annoy catboost fastai file gensim keras lightgbm mxnet onnx prophet pytorch pytorch-lightning sklearn sklearn-with-explainer skorch tensorflow transformers xgboost )
+frameworks=( annoy catboost fastai file gensim keras lightgbm \
+	mxnet onnx-sklearn onnx-lightgbm prophet pytorch pytorch-lightning sklearn \
+	sklearn-with-explainer sklearn-with-extras skorch \
+	tensorflow transformers xgboost xgboost-booster )
 
 for framework in "${frameworks[@]}"
 do
