@@ -13,7 +13,7 @@
 #    limitations under the License.
 from typing import Iterator, List
 
-from modelstore.meta.dependencies import module_exists
+from modelstore.metadata.code.dependencies import module_exists
 from modelstore.models.annoy import AnnoyManager
 from modelstore.models.catboost import CatBoostManager
 from modelstore.models.fastai import FastAIManager
@@ -76,6 +76,8 @@ def iter_libraries(storage: CloudStorage = None) -> Iterator[ModelManager]:
 
 
 def matching_managers(managers: list, **kwargs) -> List[ModelManager]:
+    """Returns the list of model managers that match with the given
+    set of kwargs"""
     managers = [m for m in managers if m.matches_with(**kwargs)]
     if len(managers) == 0:
         raise ValueError("could not find matching manager")
@@ -83,9 +85,14 @@ def matching_managers(managers: list, **kwargs) -> List[ModelManager]:
 
 
 def get_manager(name: str, storage: CloudStorage = None) -> ModelManager:
-    manager = _LIBRARIES[name](storage)
+    """Returns a model manager, given a name"""
+    if name == "keras":
+        # Older versions of modelstore (before 0.0.73) had separate
+        # managers for Keras and Tensorflow. Setting this explicitly
+        # here ensures that modelstore remains backward compatible
+        manager = TensorflowManager(storage)
+    else:
+        manager = _LIBRARIES[name](storage)
     if all(module_exists(x) for x in manager.required_dependencies()):
         return manager
-    raise ValueError(
-        "could not create manager for %s: dependencies not installed", name
-    )
+    raise ValueError(f"could not create manager for {name}: dependencies not installed")
