@@ -13,8 +13,9 @@
 #    limitations under the License.
 import os
 from functools import partial
-from typing import Any
+from typing import Any, Union
 
+from modelstore.metadata import metadata
 from modelstore.models.common import save_json
 from modelstore.models.model_manager import ModelManager
 from modelstore.storage.storage import CloudStorage
@@ -51,19 +52,40 @@ class XGBoostManager(ModelManager):
         # pylint: disable=import-outside-toplevel
         import xgboost as xgb
 
-        return isinstance(kwargs.get("model"), xgb.XGBModel)
+        return any([
+            isinstance(kwargs.get("model"), xgb.XGBModel),
+            isinstance(kwargs.get("model"), xgb.Booster)
+        ])
 
     def _get_functions(self, **kwargs) -> list:
+        # pylint: disable=import-outside-toplevel
+        import xgboost as xgb
+
+        model = kwargs["model"]
+        if isinstance(model, xgb.Booster):
+            booster = model
+        else:
+            booster = model.get_booster()
+
         return [
-            partial(save_model, model=kwargs["model"]),
-            partial(dump_model, model=kwargs["model"]),
-            partial(model_config, model=kwargs["model"]),
+            partial(save_model, model=model),
+            partial(dump_booster, booster=booster),
+            partial(save_booster_config, booster=booster),
         ]
 
-    def _get_params(self, **kwargs) -> dict:
-        return kwargs["model"].get_xgb_params()
+    def get_params(self, **kwargs) -> dict:
+        # pylint: disable=import-outside-toplevel
+        import xgboost as xgb
+
+        model = kwargs["model"]
+        if isinstance(model, xgb.Booster):
+            logger.warning("Cannot retrieve xgb params for low-level xgboost xgb.Booster object")
+            return {}
+        return model.get_xgb_params()
+
+    def load(self, model_path: str, meta_data: metadata.Summary) -> Any:
+        super().load(model_path, meta_data)
 
-    def load(self, model_path: str, meta_data: dict) -> Any:
         # pylint: disable=import-outside-toplevel
         import xgboost as xgb
 
@@ -71,9 +93,10 @@ class XGBoostManager(ModelManager):
             "XGBRegressor": xgb.XGBRegressor,
             "XGBClassifier": xgb.XGBClassifier,
             "XGBModel": xgb.XGBModel,
+            "Booster": xgb.Booster,
             # Future: other types
         }
-        model_type = self._get_model_type(meta_data)
+        model_type = meta_data.model_type().type
         if model_type not in model_types:
             raise ValueError(f"Cannot load xgboost model type: {model_type}")
 
@@ -88,7 +111,7 @@ def _model_file_path(tmp_dir: str) -> str:
     return os.path.join(tmp_dir, MODEL_FILE)
 
 
-def save_model(tmp_dir: str, model: "xgb.XGBModel") -> str:
+def save_model(tmp_dir: str, model: Union["xgb.XGBModel", "xgb.Booster"]) -> str:
     """From the docs:
     The model is saved in an XGBoost internal format which is universal
     among the various XGBoost interfaces.
@@ -99,18 +122,19 @@ def save_model(tmp_dir: str, model: "xgb.XGBModel") -> str:
     return file_path
 
 
-def dump_model(tmp_dir: str, model: "xgb.XGBModel") -> str:
+def dump_booster(tmp_dir: str, booster: "xgb.Booster") -> str:
     """From the docs:
     Dump model into a text or JSON file.  Unlike `save_model`, the
     output format is primarily used for visualization or interpretation
     """
-    logger.debug("Dumping xgboost model")
+    logger.debug("Dumping xgboost booster model")
     model_file = os.path.join(tmp_dir, MODEL_JSON)
-    model.get_booster().dump_model(model_file, with_stats=True, dump_format="json")
+    booster.dump_model(model_file, with_stats=True, dump_format="json")
     return model_file
 
 
-def model_config(tmp_dir: str, model: "xgb.XGBModel") -> str:
+def save_booster_config(tmp_dir: str, booster: "xgb.Booster") -> str:
+    """ Saves the booster config to file """
     logger.debug("Dumping model config")
-    config = model.get_booster().save_config()
+    config = booster.save_config()
     return save_json(tmp_dir, MODEL_CONFIG, config)
