@@ -17,18 +17,19 @@ import os
 import catboost as ctb
 import numpy as np
 import pytest
+
+from modelstore.metadata import metadata
 from modelstore.models import catboost
+
+# pylint: disable=unused-import
 from tests.models.utils import classification_data
 
-# pylint: disable=protected-access
-# pylint: disable=redefined-outer-name
+# pylint: disable=protected-access,redefined-outer-name,missing-function-docstring
 
 
 @pytest.fixture
 def catb_model(tmpdir, classification_data):
-    model = ctb.CatBoostClassifier(
-        loss_function="MultiClass", train_dir=str(tmpdir)
-    )
+    model = ctb.CatBoostClassifier(loss_function="MultiClass", train_dir=str(tmpdir))
     X_train, y_train = classification_data
     model.fit(X_train, y_train)
     return model
@@ -40,28 +41,14 @@ def catb_manager():
 
 
 def test_model_info(catb_manager, catb_model):
-    exp = {"library": "catboost", "type": "CatBoostClassifier"}
-    res = catb_manager._model_info(model=catb_model)
-    assert exp == res
-
-
-@pytest.mark.parametrize(
-    "ml_library,should_match",
-    [
-        ("catboost", True),
-        ("sklearn", False),
-    ],
-)
-def test_is_same_library(catb_manager, ml_library, should_match):
-    assert (
-        catb_manager._is_same_library({"library": ml_library}) == should_match
-    )
+    expected = metadata.ModelType("catboost", "CatBoostClassifier", None)
+    res = catb_manager.model_info(model=catb_model)
+    assert expected == res
 
 
 def test_model_data(catb_manager, catb_model):
-    exp = {}
-    res = catb_manager._model_data(model=catb_model)
-    assert exp == res
+    res = catb_manager.model_data(model=catb_model)
+    assert res is None
 
 
 def test_required_kwargs(catb_manager):
@@ -80,7 +67,7 @@ def test_get_functions(catb_manager, catb_model):
 
 def test_get_params(catb_manager, catb_model):
     exp = catb_model.get_params()
-    res = catb_manager._get_params(model=catb_model)
+    res = catb_manager.get_params(model=catb_model)
     assert exp == res
 
 
@@ -112,6 +99,7 @@ def test_dump_attributes(catb_model, tmp_path):
         "evals_result",
         "best_score",
     ]
+    # pylint: disable=unspecified-encoding
     with open(res, "r") as lines:
         data = json.loads(lines.read())
     assert all(x in data for x in config_keys)
@@ -120,22 +108,29 @@ def test_dump_attributes(catb_model, tmp_path):
 def test_load_model(tmp_path, catb_manager, catb_model):
     # Save the model to a tmp directory
     model_path = catboost.save_model(tmp_path, catb_model, fmt="cbm")
-    assert model_path == os.path.join(
-        tmp_path, catboost._MODEL_PREFIX.format("cbm")
-    )
+    assert model_path == os.path.join(tmp_path, catboost._MODEL_PREFIX.format("cbm"))
 
     #  Load the model
     loaded_model = catb_manager.load(
         tmp_path,
-        {
-            "model": {
-                "model_type": {
-                    "type": "CatBoostClassifier",
-                },
-            }
-        },
+        metadata.Summary(
+            model=metadata.Model(
+                domain=None,
+                model_id=None,
+                model_type=metadata.ModelType(
+                    library=None,
+                    type="CatBoostClassifier",
+                    models=None,
+                ),
+                parameters=None,
+                data=None,
+            ),
+            code=None,
+            storage=None,
+            modelstore=None,
+        ),
     )
 
     # Expect the two to be the same
-    assert type(loaded_model) == type(catb_model)
+    assert isinstance(loaded_model, type(catb_model))
     assert loaded_model.get_params() == catb_model.get_params()
