@@ -14,7 +14,7 @@
 import pytest
 from modelstore.models.missing_manager import MissingDepManager
 
-# pylint: disable=redefined-outer-name
+# pylint: disable=redefined-outer-name,missing-function-docstring
 
 
 @pytest.fixture
@@ -24,7 +24,7 @@ def missing_library_manager():
 
 def test_missing_dep_create(missing_library_manager):
     with pytest.raises(ModuleNotFoundError):
-        missing_library_manager.upload("test-domain")
+        missing_library_manager.upload("test-domain", "model-id")
 
 
 def test_missing_manager_matches_with(missing_library_manager):
@@ -33,4 +33,4 @@ def test_missing_manager_matches_with(missing_library_manager):
 
 def test_load_model(missing_library_manager):
     with pytest.raises(ModuleNotFoundError):
-        missing_library_manager.load("model-path", {})
+        missing_library_manager.load("model-path", None)
