@@ -15,11 +15,6 @@ import json
 import os
 
 import pytest
-from modelstore.models.transformers import (
-    MODEL_DIRECTORY,
-    TransformersManager,
-    _save_transformers,
-)
 from transformers import (
     AutoConfig,
     AutoModelForSequenceClassification,
@@ -31,8 +26,17 @@ from transformers import (
 )
 from transformers.file_utils import CONFIG_NAME
 
+from modelstore.metadata import metadata
+from modelstore.metadata.dataset.dataset import Features, Labels
+from modelstore.models.transformers import (
+    MODEL_DIRECTORY,
+    TransformersManager,
+    _save_transformers,
+)
+
 # pylint: disable=protected-access
 # pylint: disable=redefined-outer-name
+# pylint: disable=missing-function-docstring
 
 
 @pytest.fixture
@@ -68,26 +72,14 @@ def tr_manager():
 
 
 def test_model_info(tr_manager):
-    exp = {"library": "transformers"}
-    res = tr_manager._model_info()
+    exp = metadata.ModelType("transformers", None, None)
+    res = tr_manager.model_info()
     assert exp == res
 
 
-@pytest.mark.parametrize(
-    "ml_library,should_match",
-    [
-        ("transformers", True),
-        ("xgboost", False),
-    ],
-)
-def test_is_same_library(tr_manager, ml_library, should_match):
-    assert tr_manager._is_same_library({"library": ml_library}) == should_match
-
-
 def test_model_data(tr_manager, tr_model):
-    exp = {}
-    res = tr_manager._model_data(model=tr_model)
-    assert exp == res
+    res = tr_manager.model_data(model=tr_model)
+    assert res is None
 
 
 def test_required_kwargs(tr_manager):
@@ -117,7 +109,7 @@ def test_get_functions(tr_manager, tr_config, tr_model, tr_tokenizer):
 
 def test_get_params(tr_manager, tr_config):
     exp = tr_config.to_dict()
-    res = tr_manager._get_params(config=tr_config)
+    res = tr_manager.get_params(config=tr_config)
     assert exp == res
 
 
@@ -154,7 +146,7 @@ def test_load_model(tmp_path, tr_manager, tr_model, tr_config, tr_tokenizer):
 
     #  Load the model
     loaded_model, loaded_tokenizer, loaded_config = tr_manager.load(
-        tmp_path, {}
+        tmp_path, None
     )
 
     # Expect the two to be the same
