@@ -13,7 +13,7 @@
 #    limitations under the License.
 import json
 import os
-from unittest import mock
+import mock
 
 import pytest
 from azure.storage.blob import (
@@ -23,13 +23,14 @@ from azure.storage.blob import (
     ContainerClient,
     StorageStreamDownloader,
 )
+
+from modelstore.metadata import metadata
 from modelstore.storage.azure import AzureBlobStorage
 
 # pylint: disable=unused-import
 from tests.storage.test_utils import (
     TEST_FILE_CONTENTS,
     TEST_FILE_LIST,
-    TEST_FILE_NAME,
     file_contains_expected_contents,
     remote_file_path,
     remote_path,
@@ -39,6 +40,7 @@ from tests.storage.test_utils import (
 # pylint: disable=redefined-outer-name
 # pylint: disable=protected-access
 # pylint: disable=no-member
+# pylint: disable=missing-function-docstring
 _MOCK_CONTAINER_NAME = "existing-container"
 
 
@@ -46,9 +48,7 @@ _MOCK_CONTAINER_NAME = "existing-container"
 def mock_settings_env_vars():
     # The AzureStorage client assumes that this environ variable
     #  has been set
-    with mock.patch.dict(
-        os.environ, {"AZURE_STORAGE_CONNECTION_STRING": "test-value"}
-    ):
+    with mock.patch.dict(os.environ, {"AZURE_STORAGE_CONNECTION_STRING": "test-value"}):
         yield
 
 
@@ -73,8 +73,9 @@ def mock_container_client(container_exists: bool, files_exist: bool):
         file_exists=files_exist
     )
     if files_exist:
+        prefix = remote_path()
         mock_container_client.list_blobs.return_value = [
-            BlobProperties(name=x) for x in TEST_FILE_LIST
+            BlobProperties(name=os.path.join(prefix, x)) for x in TEST_FILE_LIST
         ]
     return mock_container_client
 
@@ -201,6 +202,7 @@ def test_remove(file_exists, should_call_delete):
             assert not file_removed
             # Asserts that we don't call delete on a file that doesn't exist
             blob_client.delete_blob.assert_not_called()
+        # pylint: disable=bare-except
     except:
         # Should fail gracefully here
         pytest.fail("Remove raised an exception")
@@ -215,8 +217,9 @@ def test_read_json_objects():
     storage = azure_storage(blob_service_client)
     # Assert that listing the files at a prefix results in 3
     # files (returned statically in the mock)
-    result = storage._read_json_objects("path/to/files")
-    storage._container_client().list_blobs.assert_called_with("path/to/files/")
+    prefix = remote_path()
+    result = storage._read_json_objects(prefix)
+    storage._container_client().list_blobs.assert_called_with(prefix + "/")
     assert len(result) == 3
 
 
@@ -243,30 +246,36 @@ def test_storage_location():
     storage = azure_storage(blob_service_client)
     # Asserts that the location meta data is correctly formatted
     prefix = "/path/to/file"
-    exp = {
-        "type": "azure:blob-storage",
-        "container": _MOCK_CONTAINER_NAME,
-        "prefix": prefix,
-    }
-    assert storage._storage_location(prefix) == exp
+    expected = metadata.Storage.from_container(
+        storage_type="azure:blob-storage",
+        container=_MOCK_CONTAINER_NAME,
+        prefix=prefix,
+    )
+    assert storage._storage_location(prefix) == expected
 
 
 @pytest.mark.parametrize(
     "meta_data,should_raise,result",
     [
         (
-            {
-                "container": _MOCK_CONTAINER_NAME,
-                "prefix": "/path/to/file",
-            },
+            metadata.Storage(
+                type=None, 
+                path=None, 
+                bucket=None,
+                container=_MOCK_CONTAINER_NAME,
+                prefix="/path/to/file"
+            ),
             False,
             "/path/to/file",
         ),
         (
-            {
-                "container": "a-different-bucket",
-                "prefix": "/path/to/file",
-            },
+            metadata.Storage(
+                type=None, 
+                path=None, 
+                bucket=None,
+                container="a-different-bucket",
+                prefix="/path/to/file"
+            ),
             True,
             None,
         ),
