@@ -15,12 +15,14 @@ import json
 import os
 
 # pylint: disable=redefined-outer-name
+# pylint: disable=missing-function-docstring
 TEST_FILE_NAME = "test-file.txt"
 TEST_FILE_CONTENTS = json.dumps({"k": "v"})
 TEST_FILE_LIST = [f"test-file-{i}.json" for i in range(3)]
 
 
 def temp_file(tmp_path, contents=TEST_FILE_CONTENTS):
+    # pylint: disable=unspecified-encoding
     source = os.path.join(tmp_path, TEST_FILE_NAME)
     with open(source, "w") as out:
         out.write(contents)
@@ -28,13 +30,14 @@ def temp_file(tmp_path, contents=TEST_FILE_CONTENTS):
 
 
 def file_contains_expected_contents(file_path):
+    # pylint: disable=unspecified-encoding
     with open(file_path, "r") as lines:
         contents = lines.read()
     return contents == TEST_FILE_CONTENTS
 
 
 def remote_path():
-    return "prefix/to/file/"
+    return "prefix/to/file"
 
 
 def remote_file_path():
