@@ -18,12 +18,13 @@ import pytest
 from modelstore.storage.util import paths
 
 # pylint: disable=protected-access
+# pylint: disable=missing-function-docstring
 
 
 @pytest.mark.parametrize("has_root_prefix", [(True), (False)])
 def test_get_archive_path(tmp_path, has_root_prefix):
     root = str(tmp_path) if has_root_prefix else ""
-    prefix = datetime.now().strftime("%Y/%m/%d/%H:%M:%S")
+    prefix = datetime.now().strftime("%Y.%m.%d-%H.%M.%S")
     exp = os.path.join(
         root, paths.MODELSTORE_ROOT_PREFIX, "domain", prefix, "file-name"
     )
@@ -32,20 +33,20 @@ def test_get_archive_path(tmp_path, has_root_prefix):
 
 
 @pytest.mark.parametrize("has_root_prefix", [(True), (False)])
-def test_get_versions_path_no_root_prefix(tmp_path, has_root_prefix):
+def test_get_models_path_no_root_prefix(tmp_path, has_root_prefix):
     root = str(tmp_path) if has_root_prefix else ""
     exp = os.path.join(root, paths.MODELSTORE_ROOT_PREFIX, "example-domain", "versions")
-    res = paths.get_versions_path(root, "example-domain")
+    res = paths.get_models_path(root, "example-domain")
     assert exp == res
 
 
 @pytest.mark.parametrize("has_root_prefix", [(True), (False)])
-def test_get_versions_path_with_state(tmp_path, has_root_prefix):
+def test_get_models_path_with_state(tmp_path, has_root_prefix):
     root = str(tmp_path) if has_root_prefix else ""
     exp = os.path.join(
         root, paths.MODELSTORE_ROOT_PREFIX, "example-domain", "versions", "prod"
     )
-    res = paths.get_versions_path(root, "example-domain", "prod")
+    res = paths.get_models_path(root, "example-domain", "prod")
     assert exp == res
 
 
@@ -79,17 +80,3 @@ def test_get_model_state_path(tmp_path, has_root_prefix):
     exp = os.path.join(root, paths.MODELSTORE_ROOT_PREFIX, "model_states", "prod.json")
     res = paths.get_model_state_path(root, "prod")
     assert exp == res
-
-
-@pytest.mark.parametrize(
-    "state_name,is_valid",
-    [
-        (None, False),
-        ("", False),
-        ("a", False),
-        ("path/to/place", False),
-        ("other", True),
-    ],
-)
-def test_is_valid_state_name(state_name, is_valid):
-    assert paths.is_valid_state_name(state_name) == is_valid
